==> v1.0.0.zip: general_channel/src/Controllers/BaseControllerConfig.php <==
<?php

namespace General\Controllers;

use General\Models\Channel\Channel;
use General\Models\Channel\ChannelUser;
use General\Models\Channel\ChannelUsersInner;
use Illuminate\Database\Eloquent\Model;

/**
 * @property int $channel_id 站点ID
 * @property string $phone 登录手机号
 * @property array $inner_phones 登录手机号
 * @property ChannelUser $channel_user 分销后台账号
 * @property int $channel_user_id 分销后台账号ID
 * @property string $channel_name 分销渠道名称
 * @property string $channel_domain 分销渠道域名
 * @property int $company_id 公司ID
 * @property array $company_channel_ids 公司属下所有渠道ID
 * @property array $user_channel_ids 账号属下所有渠道ID
 * @property bool $is_inner 是否为内部站点
 * @property int $sj_status 审计状态
 * @property bool $is_sj_inner 是否为审计内部站点
 */
trait BaseControllerConfig
{
    public function __get($name)
    {
        if (!isset($this->$name)) {
            return $this->$name();
        }
    }

    protected function channel()
    {
        if (empty(session('ydychannel'))) {
            if (env('APP_ENV') == 'local') return Channel::find(1);
        }
        return unserialize(session('ydychannel'));
    }

    protected function sj_status()
    {
        return redisEnv('SHENJI_SWITCH') ? 1 : 0;
    }


    protected function is_sj_inner(): bool
    {
        return in_array($this->phone, $this->inner_phones);
    }

    protected function inner_phones(): array
    {
        return ChannelUsersInner::where('is_enable', 1)->pluck('phone')->all();
    }

    protected function channel_id(): int
    {
        return $this->channel->id;
    }

    protected function channel_name(): string
    {
        return $this->channel->distribution_channel_name;
    }

    protected function channel_domain(): string
    {
        return "site{$this->channel_id}.leyuee.com";
    }

    protected function channel_user_id(): int
    {
        return session('ydyauth');
    }

    protected function phone(): string
    {
        return session('ydylogphone');
    }

    protected function company_id(): int
    {
        return $this->channel_user->id;
    }

    protected function channel_user(): ChannelUser
    {
        return ChannelUser::find($this->channel_user_id);
    }

    protected function company_channel_ids(): array
    {
        $channel_user_ids = ChannelUser::where('company_id', $this->company_id)->pluck('id')->all();
        return Channel::whereIn('channel_user_id', $channel_user_ids)->pluck('id')->all();
    }

    protected function is_inner(): bool
    {
        $inner_phones = [];
        foreach ($this->inner_phones as $item) {
            $inner_phones[] = $item . '2';
        }
        return in_array($this->phone, $inner_phones);
    }

    protected function user_channel_ids(): array
    {
        return Channel::where('channel_user_id', $this->channel_user_id)->get()->pluck('id')->all();
    }
}

==> v1.0.3.zip: general_channel/src/Controllers/BaseControllerConfig.php <==
<?php

namespace General\Controllers;

use General\Models\Channel\Channel;
use General\Models\Channel\ChannelUser;
use General\Models\Channel\ChannelUsersInner;
use Illuminate\Database\Eloquent\Model;

/**
 * @property int $channel_id 站点ID
 * @property string $phone 登录手机号
 * @property array $inner_phones 登录手机号
 * @property ChannelUser $channel_user 分销后台账号
 * @property int $channel_user_id 分销后台账号ID
 * @property string $channel_name 分销渠道名称
 * @property string $channel_domain 分销渠道域名
 * @property int $company_id 公司ID
 * @property array $company_channel_ids 公司属下所有渠道ID
 * @property array $user_channel_ids 账号属下所有渠道ID
 * @property bool $is_inner 是否为内部站点
 * @property int $sj_status 审计状态
 * @property bool $is_sj_inner 是否为审计内部站点
 */
trait BaseControllerConfig
{
    public function __get($name)
    {
        if (!isset($this->field[$name])) {
            return $this->$name();
        }
    }

    protected function channel(): Model
    {
        if (empty(session('ydychannel'))) {
            if (env('APP_ENV') == 'local') return Channel::find(1);
        }
        return unserialize(session('ydychannel'));
    }

    protected function sj_status()
    {
        return redisEnv('SHENJI_SWITCH') ? 1 : 0;
    }

    protected function is_sj_inner(): bool
    {
        return in_array($this->phone(), $this->getInnerPhone());
    }

    protected function inner_phones(): array
    {
        return ChannelUsersInner::where('is_enable', 1)->pluck('phone')->all();
    }

    protected function channel_id(): int
    {
        return $this->channel->id;
    }

    protected function channel_name(): string
    {
        return $this->channel->distribution_channel_name;
    }

    protected function channel_domain(): string
    {
        return "site{$this->channel_id}.leyuee.com";
    }

    protected function channel_user_id(): int
    {
        return session('ydyauth');
    }

    protected function phone(): string
    {
        return session('ydylogphone');
    }

    protected function company_id(): int
    {
        return $this->channel_user->id;
    }

    protected function channel_user(): ChannelUser
    {
        return ChannelUser::find($this->channel_user_id);
    }

    protected function company_channel_ids(): array
    {
        $channel_user_ids = ChannelUser::where('company_id', $this->company_id)->pluck('id')->all();
        return Channel::whereIn('channel_user_id', $channel_user_ids)->pluck('id')->all();
    }

    protected function is_inner(): bool
    {
        $inner_phones = [];
        foreach ($this->inner_phones as $item) {
            $inner_phones[] = $item->phone . '2';
        }
        return in_array($this->phone, $inner_phones);
    }

    protected function user_channel_ids(): array
    {
        return Channel::where('channel_user_id', $this->channel_user_id)->get()->pluck('id')->all();
    }
}
